@@ -39,16 +39,15 @@
 #include "prtOpt.h"
 
 #define LINE_BUFFER 1024
-#define ARRAY_MAX 14
+#define ARRAY_MAX 64
 #define SUB_MAX 3
 
-#define GLOBAL_OPTIONS_NOMBER 3
+#define GLOBAL_OPTIONS_NOMBER 1
 #define PIPS_UI_MODE 0
-#define PIPS_LANG 1
-#define PIPS_INPUT_FILE_TYPE 2
 
 const char *gopts[] = {
-  "ui" /* select UI */
+  "ui", /* select UI */
+  "ft"  /* select Input file type */
 };
 
 const char *opts[] = {
@@ -56,7 +55,7 @@ const char *opts[] = {
   "in", "ink",             /* id = 1 */
   "ms", "mediasize",       /* id = 2 */
   "re", "resolution",      /* id = 3 */
-  "mt", "mediatipe",       /* id = 4 */
+  "mt", "mediatype",       /* id = 4 */
   "cc", "colorcorrection", /* id = 5 */
   "br", "brightness",      /* id = 6 */
   "co", "contrast",        /* id = 7 */
@@ -72,7 +71,15 @@ const char *opts[] = {
   NULL
 };
 
+/* A revision of notation mistake. */
+const char *opts_strings_mistake[] =
+{
+  "mediatipe", "mediatype",
+  NULL
+};
+
 extern void *opt_address[EX_N_OPT];
+extern int Lang;
 
 static int globalInitOpts(char*, int, PIPS_INIT_PARAM*);
 static int getRscError(SEP_INIT_PARAM*, int, int, FILE*);
@@ -83,6 +90,8 @@ static void defSet(SEP_INIT_PARAM *);
 static int setConf(int id, SEP_INIT_PARAM *sepip, char sub[SUB_MAX][ARRAY_MAX]);
 static int valueCheck(int id, char sub[SUB_MAX][ARRAY_MAX]);
 
+static int check_peculiar_to_model (const short*, int, SEP_INIT_PARAM*);
+
 /*--------------------------------------------------*/
 /*          globalInitOpts                          */
 /*--------------------------------------------------*/
@@ -94,9 +103,13 @@ globalInitOpts (char *strv, int opt_id, PIPS_INIT_PARAM *pip)
   switch (opt_id)
     {
     case PIPS_UI_MODE:
-      if (!strncmp (strv, "X", 1)) value = 0;
-      else if (!strncmp (strv, "C", 1)) value = 1;
-      else return 1;
+      if (!strncmp (strv, "X", 1))
+	value = 0;
+      else if (!strncmp (strv, "C", 1))
+	value = 1;
+      else
+	return 1;
+
       pip->action_mode = value;
       break;
 
@@ -133,15 +146,15 @@ xMode (int argc, char *argv[], char *filename,
 /*##################################################*/
 
 int
-cMode (char *filename, SEP_INIT_PARAM *sepip, PIPS_INIT_PARAM *pip)
+cMode (char *infile, SEP_INIT_PARAM *sepip, PIPS_INIT_PARAM *pip)
 {
 #ifdef CONV_VERSION2
-  return graphics_converter_version2 (sepip, filename, NULL);
+  return graphics_converter_version2 (sepip, infile, NULL);
 
 #else
   FILE *fp = stdout;
 
-  return printLoop (filename, fp, sepip);
+  return printLoop (infile, fp, sepip);
 #endif
 }
 
@@ -174,8 +187,8 @@ databasesCall (int frag, int id, void *entry)
     {
       for (i = 0; data[i].value != END_ARRAY; i++)
 	{
-	      if(!strcmp ((char*)entry, data[i].x_name))
-		      return (data + i);
+	  if(!strcmp ((char*)entry, data[i].x_name))
+	    return (data + i);
 	}
     }
   /* add Mon Aug 28 2000 sk */
@@ -242,10 +255,19 @@ getRsc (SEP_INIT_PARAM *sepip)
 	      getRscError (sepip, lin_No, RESOURCE_FORM_ERROR, fp);
 	      return NO_ERROR;
 	    }
+
 	  size = strlen (p_name);
+	  /* A revision of notation mistake. */
+	  for (i = 0; opts_strings_mistake[i * 2]; i++)
+	    {
+	      if (!strncmp (p_name, opts_strings_mistake[i * 2], size))
+		{
+		  strcpy (p_name, opts_strings_mistake[i * 2 + 1]);
+		}
+	    }
 	  for (p_id = 0; p_id < N_OPT; p_id++)
 	    {
-	      if (!strncmp(lin, opts[p_id * 2 + 1], size))
+	      if (!strncmp(p_name, opts[p_id * 2 + 1], size))
 		{
 		  size++;
 		  if (sscanf (lin + size, "%s", p_sub) != 1)
@@ -283,7 +305,9 @@ getRsc (SEP_INIT_PARAM *sepip)
 static int
 getRscError (SEP_INIT_PARAM *sepip, int lin_No, int error_code, FILE *fp)
 {
-  if (fp != NULL) fclose(fp);
+  if (fp != NULL)
+    fclose(fp);
+
   if (lin_No != -1)
     {
       char lin_No_c[128];
@@ -315,15 +339,16 @@ saveRsc (void *save_options[])
 
 
   user_id = geteuid ();
+
   if ((fp = fopen (RSC_PATH, "a+b")) == NULL)
   {
-	  fprintf (stderr, "PIPS Warning : Resource file not found or resource not set. Do save with root.\n");
+	  fprintf (stderr, "PIPS Warning : Non Resource File. Do save with root.\n");
 	  return;
   }
   fclose (fp);
-  
+
   if ((fp = fopen (RSC_PATH, "rb")) == NULL) return;
-  
+
   switch (scanRscFile (fp))
     {
     case -1:
@@ -390,7 +415,8 @@ saveRsc (void *save_options[])
 	case P_BRIGHTNESS:
 	case P_CONTRAST:
 	case P_SATURATION:
-	  fprintf (fp, "%d\n", *((int*)save_options[i])); break;
+	  fprintf (fp, "%d\n", *((int*)save_options[i]));
+	  break;
 
 	case P_INK:
 	case P_MEDIA_SIZE:
@@ -400,7 +426,8 @@ saveRsc (void *save_options[])
 	case P_COLOR_MODE:
 	case P_QUALITY_LEVEL:
 	case P_BIN:
-	  fprintf (fp, "%s\n", (char*)save_options[i]); break;
+	  fprintf (fp, "%s\n", (char*)save_options[i]);
+	  break;
 
 	case P_STRENGTH:
 	  fprintf (fp, "%d, ", *((int*)save_options[P_STRENGTH_CYAN]));
@@ -604,8 +631,8 @@ getOptsForX (void *options[], SEP_INIT_PARAM *sepip)
 	  break;
 
 	case P_HIGH_SPEED:
-	  if(options[P_HIGH_SPEED] != NULL)
-	    strcpy (sub_arg[0], (char *)options[P_HIGH_SPEED]);
+	  if(options[i] != NULL)
+	    strcpy (sub_arg[0], (char *)options[i]);
 	  else
 	    strcpy (sub_arg[0], "OFF");
 	  break;
@@ -663,19 +690,12 @@ checkConf (SEP_INIT_PARAM *sepip)
 	      msizeEntry = mediaSizeEntry; break;
 	    case PIPS_BIN_USER:
 	      msizeEntry = mediaSizeEntry_R; break;
-#if !(PM820_3300C)
 	    case PIPS_BIN_TRIMBANNER:
 	      msizeEntry = mediaSizeEntry_TR; break;
-#else
-	    case PIPS_BIN_TB_PM3300C:
-	      msizeEntry = mediaSizeEntry_TR_PM3300C; break;
-	    case PIPS_BIN_TB_PM820C:
-	      msizeEntry = mediaSizeEntry_TR_PM820C; break;
-#endif /* PM820_3300C */
-#if (PM820C)
-	    case PIPS_BIN_AUTO_TRIM:
-	      msizeEntry = mediaSizeEntry_TA; break;
-#endif /* PM820C */
+#ifdef USE_AUTO_TRIM_4
+	    case PIPS_BIN_AUTO_TRIM_4:
+	      msizeEntry = mediaSizeEntry_NMA; break;
+#endif /* USE_AUTO_TRIM_4 */
 	    default: return 1;
 	
 	    }
@@ -705,10 +725,18 @@ printModeCheck (const short *mode, int count, SEP_INIT_PARAM *sepip)
 {
   int ofs;
 
+  /* A parameter check peculiar to a model of machines */
+  /* add Fri Nov 24 2000 sk */
+  if (check_peculiar_to_model (mode, count, sepip))
+    {
+      return 1;
+    }
+
   ofs = count * MODE_ITEM + 1;
 
+  if (sepip->media_type < 0) return 0;
   if (sepip->media_type != mode[ofs]) return 1;
-  
+ 
   if (sepip->src_resolution.x >= 0)
     {
       int bit = 0;
@@ -716,8 +744,14 @@ printModeCheck (const short *mode, int count, SEP_INIT_PARAM *sepip)
 	{
 	case 120:
 	case 180: bit = 1; break;
+#if SC580 || SC480 || SC40S || SC20S
+	case 240: bit = 2; break;
+	case 360: bit = 4; break;
+	case 720: bit = 8; break;
+#else
 	case 360: bit = 2; break;
 	case 720: bit = 4; break;
+#endif
 	}
       if (!(mode[ofs + 1] & bit)) return 1;
     }
@@ -733,6 +767,11 @@ printModeCheck (const short *mode, int count, SEP_INIT_PARAM *sepip)
 	  
 	case 720: bit = bit >> 4;
 	case 360: bit = bit >> 4;
+
+#if SC580 || SC480 || SC40S || SC20S
+	case 240: bit = bit >> 4;
+#endif
+
 	  bit &= 0x0f;
 	  if (bit != sepip->qlevel) return 1;
 	  break;
@@ -770,8 +809,9 @@ existsp(char *lin)
   int i, j;
   
   j = 0;
-  
-  for (i = 0; lin[i] != '\0' || lin[i]; i++)
+  tmp_lin[0] = '\0';
+
+  for (i = 0; lin[i] != '\0'; i++)
     if (!isspace (lin[i])) tmp_lin[j++] = lin[i];
   
   if (tmp_lin[j - 1] != '\0')
@@ -916,7 +956,7 @@ valueCheck (int id, char sub[SUB_MAX][ARRAY_MAX])
   int i, j;
   int value;
   int count = 0;
-  char **entry;
+  char **entry = 0;
 
   switch (id)
     {
@@ -983,3 +1023,46 @@ valueCheck (int id, char sub[SUB_MAX][ARRAY_MAX])
     }
   return 1;
 }
+
+/* A parameter check peculiar to a model of machines */
+/* add Fri Nov 24 2000 sk */
+static int
+check_peculiar_to_model (const short *mode, int count,
+			 SEP_INIT_PARAM *sepip)
+{
+#ifdef USE_AUTO_TRIM_4
+  if (sepip->bin_id == PIPS_BIN_AUTO_TRIM_4)
+    {
+      int i;
+      short *de_mode_list;
+#ifdef PM900C
+      de_mode_list = de_param_mode_t4_for_pm900c;
+#elif PM880C
+      de_mode_list = de_param_mode_t4_for_pm880c;
+#elif PM780C
+      de_mode_list = de_param_mode_t4_for_pm780c;
+#elif PM3500C
+      de_mode_list = de_param_mode_t4_for_pm3500c;
+#elif PM790PT
+      de_mode_list = de_param_mode_t4_for_pm790pt;
+#elif PM920C
+      de_mode_list = de_param_mode_t4_for_pm920c;
+#elif PM780CS
+      de_mode_list = de_param_mode_t4_for_pm780cs;
+#elif PM820CUG
+      de_mode_list = de_param_mode_t4_for_pm820cug;
+#elif PM3300CUG
+      de_mode_list = de_param_mode_t4_for_pm3300cug;
+#elif SP810_820
+      de_mode_list = de_param_mode_t4_for_sp810_820;
+#endif
+      for (i = 0; de_mode_list[i] != -1; i++)
+	{
+	  if (de_mode_list[i] == count)
+	    return 1;
+	}
+    }
+#endif /* USE_AUTO_TRIM_4 */
+
+  return 0;
+}
