@@ -24,6 +24,10 @@
  * respects for all of the code used other than the libraries which
  * are covered by EPSON KOWA PUBLIC LICENCE.
  */
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #ifndef __PF_DEF_H__
 #define __PF_DEF_H__
 
