@@ -29,14 +29,20 @@
 #endif
 
 #include <stdio.h>
-#include <string.h>
 #include <math.h>
 
+#ifdef _V1_SUPPORT
+#include <string.h>
+#endif /* _V1_SUPPORT */
+/* #include <setjmp.h> */
+
 #include "pfpng_ext.h"
+
 #include "pfimg.h"
 #include "pfmem.h"
 #include "libprtX.h"
 #include "pferr.h"
+#include "setup.h"
 
 /* rgbǡǼbufferΥ */
 #define DEFAULT_BUFFER_SIZE 0xfffff
@@ -48,40 +54,40 @@
 ((center * 2 + left1 + right1) * 4 + left1 + right1 - left3 - right3) / 16
 
 enum nCONVRSION_STATUS
-{
-	CONV_STATUS_INIT = 0,
-	CONV_STATUS_PAGE_INIT,
-	CONV_STATUS_BAND_OUT,
-	CONV_STATUS_PAGE_END,
-	CONV_STATUS_END,
-	CONV_STATUS_PNG_ERROR
-};
+	{
+		CONV_STATUS_INIT = 0,
+		CONV_STATUS_PAGE_INIT,
+		CONV_STATUS_BAND_OUT,
+		CONV_STATUS_PAGE_END,
+		CONV_STATUS_END,
+		CONV_STATUS_PNG_ERROR
+	};
 
 /* Ԥ᡼Ǽ */
 typedef struct _PNG_IMAGE_STRUCT
 {
-	FILE*   ifp;			/* ϥȥ꡼ؤΥݥ */
-	HANDLE  png_ptr;		/* libpngǻ */
-	HANDLE  info_ptr;		/* libpngǻ */
-	int     image_pass;		/* Interleceк */
-	POINT   image_size;		/* ᡼Υ */
-	POINT   print_size;		/* (ºݤlibraryФ)
-					   ᡼Υ */
-	DPOINT  magnify;		/* /̾Ψ */
-	POINT   negative_margin;	/* ޥʥޡ
-					   ޡ󤬥ޥʥˤʤˤ,ΤΤڤɬפ
-					   ޡ󤬥ץ饹ξ硢ˤ0 */
-	int     byte_p_pixel;		/* 1pixelɬפʥХȿ */
-	long    read_line;		/* ɤ߹饹 */
-	int     num_line;		/* Ǽ饹 */
-	UCHAR** rows;			/* 饹ǡǼbuffer */
+	FILE*   ifp;                  /* ϥȥ꡼ؤΥݥ */
+	HANDLE  png_ptr;              /* libpngǻ */
+	HANDLE  info_ptr;             /* libpngǻ */
+	int     image_pass;           /* Interleceк */
+	POINT   image_size;           /* ᡼Υ */
+	POINT   print_size;           /* (ºݤlibraryФ)
+					 ᡼Υ */
+	DPOINT  magnify;              /* /̾Ψ */
+	POINT   negative_margin;      /* ޥʥޡ
+					 ޡ󤬥ޥʥˤʤˤ,ΤΤڤɬפ
+					 ޡ󤬥ץ饹ξ硢ˤ0 */
+	int     byte_p_pixel;         /* 1pixelɬפʥХȿ */
+	long    read_line;            /* ɤ߹饹 */
+	int     num_line;             /* Ǽ饹 */
+	UCHAR** rows;                 /* 饹ǡǼbuffer */
 } IMG_STRUCT, *LP_IMG_STRUCT;
 
 
 /* Static functions */
 
 /* mkcode_init -LibraryɤơԤ
-                mkcode¤ΤlibraryؤΥݥ󥿤Ǽ
+   mkcode¤ΤlibraryؤΥݥ󥿤Ǽ
     :   LP_MKC_STRUCT mkcodeζͭؤΥݥ
     : BOOL          0 ==, 1== */
 static BOOL
@@ -106,58 +112,58 @@ static BOOL
 mkcode_page_end (LP_MKC_STRUCT, int);
 
 /* image_to_printer -᡼Ѵ롼פκǾ̴ؿ
-                     Ϥ줿եФ˽Ԥ
-		     mkcode¤Τϥȥ꡼ؤΥݥ󥿤Ǽ
+   Ϥ줿եФ˽Ԥ
+   mkcode¤Τϥȥ꡼ؤΥݥ󥿤Ǽ
     :   LP_MKC_STRUCT mkcodeζͭؤΥݥ
     : BOOL          0 ==, 1== */
 static BOOL
 image_to_printer (LP_MKC_STRUCT);
 
 /* image_convert_to_code -ȥ꡼¸ߤФ,
-                          ˽Ԥ
+   ˽Ԥ
     :   FILE*         륹ȥ꡼ؤΥݥ
-            LP_MKC_STRUCT mkcodeζͭؤΥݥ
+   LP_MKC_STRUCT mkcodeζͭؤΥݥ
     : BOOL          0 ==, 1== */
 static BOOL
 image_convert_to_code (FILE*, LP_MKC_STRUCT);
 
 /* load_image_init -PNG᡼ξ
-                    img¤Τۤmkcode¤Τ˳Ǽ
+   img¤Τۤmkcode¤Τ˳Ǽ
     :   LP_IMG_STRUCT оݤImageǼ빽¤ΤؤΥݥ
-            LP_MKC_STRUCT mkcodeζͭؤΥݥ
+   LP_MKC_STRUCT mkcodeζͭؤΥݥ
     : BOOL          0 ==, 1== */
 static BOOL
 load_image_init (LP_IMG_STRUCT, LP_MKC_STRUCT);
 
 /* load_image_end -libpngνλԤ, libpngλѤƤ
-                   ꡼롣λǤϡޤȥ꡼
-                   ƤϤʤ
+   ꡼롣λǤϡޤȥ꡼
+   ƤϤʤ
     :   LP_IMG_STRUCT оݤImageǼ빽¤ΤؤΥݥ
     : void */
 static void
 load_image_end (LP_IMG_STRUCT);
 
 /* png_setup -PNG᡼ɤ߹߻λͤꤹ
-              Colorʤ,24bitRGBǡꤷ,
-              Monochromeʤ,8bitGrayǡꤹ
+   Colorʤ,24bitRGBǡꤷ,
+   Monochromeʤ,8bitGrayǡꤹ
     :   LP_IMG_STRUCT оݤImageǼ빽¤ΤؤΥݥ
-            char*         formatϤcolorڤ, mono
-                          ǡlibpngƤΤ
+   char*         formatϤcolorڤ, mono
+   ǡlibpngƤΤ
     : BOOL          0 ==, 1== */
 static BOOL
 png_setup (LP_IMG_STRUCT, char*);
 
 
 /* load_image_out -ºݤ˥饹libraryǽԤ
-                   /̾⤳ǹԤ
+   /̾⤳ǹԤ
     :   LP_IMG_STRUCT оݤImageǼ빽¤ΤؤΥݥ
-            LP_MKC_STRUCT mkcodeζͭؤΥݥ
+   LP_MKC_STRUCT mkcodeζͭؤΥݥ
     : BOOL          0 ==, 1== */
 static BOOL
 load_image_out (LP_IMG_STRUCT, LP_MKC_STRUCT);
 
 /* read_raster_image -1饹ʬβǡѰդ, 
-                      ƬؤΥݥ󥿤֤
+   ƬؤΥݥ󥿤֤
     :   LP_IMG_STRUCT оݤImageǼ빽¤ΤؤΥݥ
     : UCHAR*        ǡƬؤΥݥ */
 static UCHAR*
@@ -168,29 +174,29 @@ seek_image (LP_IMG_STRUCT);
 
 /* conf_print_image -
     :   LP_PRT_STURCT ⡼ɾ
-            LP_IMG_STRUCT оݤImageǼ빽¤ΤؤΥݥ
+   LP_IMG_STRUCT оݤImageǼ빽¤ΤؤΥݥ
     : void */
 static void
 conf_print_image (LP_PRT_STRUCT, LP_IMG_STRUCT);
 
 /* set_init_param -prt_init򥻥å
     :   LP_LIBPRT_INIT DLL_PRT_INITϤι¤Τͤ򥻥åȤ
-            LP_PRT_STRUCT  ⡼ɾ
-            char*          ϥե̾(NULLʤɸ)
+   LP_PRT_STRUCT  ⡼ɾ
+   char*          ϥե̾(NULLʤɸ)
     : void */
 static void
 set_init_param (LP_LIBPRT_INIT, LP_PRT_STRUCT, FILE*);
 
 /* set_page_param -prt_page򥻥å
     :   LP_LIBPRT_PAGE   DLL_PAGE_INITϤι¤Τͤ򥻥åȤ
-            LP_PRT_STRUCT ⡼ɾ
+   LP_PRT_STRUCT ⡼ɾ
     : void */
 static void
 set_page_param (LP_LIBPRT_PAGE, LP_PRT_STRUCT);
 
 /* set_band_param -prt_band򥻥å
     :   LP_LIBPRT_BAND   DLL_BAND_OUTϤι¤Τͤ򥻥åȤ
-            LP_IMG_STRUCT оݤImageǼ빽¤ΤؤΥݥ
+   LP_IMG_STRUCT оݤImageǼ빽¤ΤؤΥݥ
     : BOOL          0 ==, 1== */
 static BOOL
 set_band_param (LP_LIBPRT_BAND, LP_IMG_STRUCT);
@@ -203,44 +209,47 @@ free_band_param (LP_LIBPRT_BAND);
 
 /* write_judge -ߤνԤȳΨ񤭹߲ԲĤȽǤ
     :   long   Υ饹ǡθ߹
-            long   Υ᡼ǡθ߹
-            double Ψ(%)
+   long   Υ᡼ǡθ߹
+   double Ψ(%)
     : BOOL          0 ==񤭹Բ, 1==񤭹߲ */
 static BOOL
 write_judge (long, long, double);
 
 #ifdef _V1_SUPPORT
 /* escp_through -ESC/PɤɤФ
-                 ,v1Ȥθߴΰ٤¸ߤv2ǤϺͽ
+   ,v1Ȥθߴΰ٤¸ߤv2ǤϺͽ
     :   FILE*  ϥեݥ
-            FILE*  ϥեݥ
-            char*  ɤ߹ХåեؤΥݥ
-            int    ɤ߹ХåեΥ
+   FILE*  ϥեݥ
+   char*  ɤ߹ХåեؤΥݥ
+   int    ɤ߹ХåեΥ
     : BOOL   -1 == esc/p (not error), 1== not esc/p */
 static BOOL
 escp_through (FILE*, FILE*, char*, int);
 #endif /* _V1_SUPPORT */
 
 static BOOL
-band_flush (void*, HANDLE, LP_LIBPRT_BAND, UCHAR *, UCHAR *, BOOL);
-
-static void
-set_raster (UCHAR *, UCHAR *, int, int, double, int);
+band_flush (OUT_FUNC, HANDLE, LP_LIBPRT_BAND, UCHAR*, BOOL);
 
 /**************************************************
  * public functions
  **************************************************/
 /* make_code_process -libPrtXXX˥ˤ,imageESC/PѴ
     :   LP_MKC_STRUCT ι¤Τˤ,ɬפʥ饤֥ؤΥѥ
-                          Ϥ줿եΥꥹȡڤӰѥ᡼
-			  ͽǼƤ
+   Ϥ줿եΥꥹȡڤӰѥ᡼
+   ͽǼƤ
     : void */
 BOOL
 make_code_process (LP_MKC_STRUCT lp_mkcode)
 {
+	/*
+	  if (fork() == 0)
+	  {
+	  if (fork() == 0)
+	  {
+        */
 	FILE* outfp = NULL;
 	int eflag = 0;
-
+          
 	/* 򳫤 */
 	if (lp_mkcode->output_file == NULL)
 	{
@@ -252,7 +261,7 @@ make_code_process (LP_MKC_STRUCT lp_mkcode)
 		   version2Ǥϡͽ */
 #ifdef _LPR_DIRECT
 		if (strcmp (lp_mkcode->output_file, "."))
-		{
+                {
 #endif /* _LPR_DIRECT */
 			outfp = fopen (lp_mkcode->output_file, "wb");
 			if (outfp == NULL)
@@ -262,31 +271,29 @@ make_code_process (LP_MKC_STRUCT lp_mkcode)
 				/* exit (1); */
 			}
 #ifdef _LPR_DIRECT
-		}
+                }
 		else
-		{
+                {
 			char prt_name[107];
 
 			strcpy (prt_name, "lpr -P");
-			/* get_prt_name (prt_name + 6); */
-			strncat (prt_name, SPOOL_NAME, 100);
+			get_prt_name (prt_name + 6);
 			outfp = popen (prt_name, "w");
 			if (outfp == NULL)
 				fprintf (stderr, "PIPS Error : Not able to communicate to lpr\n");
-		}
+                }
 #endif /* _LPR_DIRECT */
 	}
 
 	lp_mkcode->output_fp = outfp;
 	lp_mkcode->conv_status = 0;
-
 	/* Ѵ */
 	eflag = image_to_printer (lp_mkcode);
-	
+          
 	/* λ */
 	if (lp_mkcode->conv_status)
 		eflag |= mkcode_lib_end (lp_mkcode);
-	
+          
 	if (lp_mkcode->output_file != NULL)
 	{
 #ifdef _LPR_DIRECT
@@ -308,6 +315,18 @@ make_code_process (LP_MKC_STRUCT lp_mkcode)
 		return 1;
 		/* exit (eflag); */
 	}
+	/*
+	  }
+
+	  exit (0);
+	  }
+	  else
+	  {
+	  int stat;
+
+	  wait (&stat);
+	  }
+	*/
 	return 0;
 }
 
@@ -474,7 +493,7 @@ image_to_printer (LP_MKC_STRUCT lp_mkcode)
 				return 1;
 			}
 		}
-
+      
 		eflag = image_convert_to_code (fp, lp_mkcode);
       
 		if (!in_flag)
@@ -511,14 +530,14 @@ image_convert_to_code (FILE* fp, LP_MKC_STRUCT lp_mkcode)
 					lp_mkcode);
 		switch (stat)
 		{
-		case 1:		/* ɤ߹ߥ顼 */
+		case 1:         /* ɤ߹ߥ顼 */
 			eflag = 1;
 
-		case -1:		/* λ */
+		case -1:                /* λ */
 			loop_flag = 0;
 			continue;
 
-		case 0:			/* ߽λ */
+		case 0:                 /* ߽λ */
 			/* libraryɤ,  */
 			if (!lp_mkcode->conv_status)
 			{
@@ -571,10 +590,10 @@ load_image_init (LP_IMG_STRUCT lp_image, LP_MKC_STRUCT lp_mkcode)
 		  ver / 10000,
 		  ( ver / 100 )  % 100,
 		  ver % 100 );
-	
+
 	if (fread (header, sizeof (char), PNG_CHECK_NUMBER, fp)
 	    != PNG_CHECK_NUMBER)
-		return -1;		/* ̵(λɽ) */
+		return -1;                /* ̵(λɽ) */
 	/* formatΥå */
 	if (dl_png_sig_cmp (header, (png_size_t)0, PNG_CHECK_NUMBER))
 	{
@@ -694,7 +713,7 @@ png_setup (LP_IMG_STRUCT lp_image, char* format)
 		dl_png_set_strip_alpha(png_ptr);
 
 	/* 顼ξ3byteBGRˡΥξ1byteꤹ */
-	if (!strcmp (format, "MONO"))	/* Υ */
+	if (!strcmp (format, "MONO")) /* Υ */
 	{
 		if (color_type == PNG_COLOR_TYPE_RGB
 		    || color_type == PNG_COLOR_TYPE_RGB_ALPHA
@@ -704,7 +723,7 @@ png_setup (LP_IMG_STRUCT lp_image, char* format)
 		width_byte = WIDTHBYTES(width * 8);
 		line = DEFAULT_BUFFER_SIZE / width_byte;
 	}
-	else				/* 顼 */
+	else                          /* 顼 */
 	{ 
 		if (color_type == PNG_COLOR_TYPE_GRAY
 		    || color_type == PNG_COLOR_TYPE_GRAY_ALPHA
@@ -748,89 +767,112 @@ png_setup (LP_IMG_STRUCT lp_image, char* format)
 static BOOL
 load_image_out (LP_IMG_STRUCT lp_image, LP_MKC_STRUCT lp_mkcode)
 {
+	int height_count, width_count;
+	DPOINT magnify;
+	POINT print_count, margin_count;
 	LIBPRT_BAND prt_band;
 
-	long h_ofs;
+	long h_ofs, w_ofs;
+	HANDLE lib_handle = lp_mkcode->lib_handle;
 	HANDLE prt_handle = lp_mkcode->prt_handle;
 	UCHAR *raster;
-	void* func;
-	long h_prt_count, h_img_count;
-	double h_mag;
-
-	conf_print_image (lp_mkcode->lp_prtinfo, lp_image);
-
-	func = (void *)dlsym (lp_mkcode->lib_handle, DLL_BAND_OUT);
-
-	if (set_band_param (&prt_band, lp_image))
-		return 1;
+	OUT_FUNC func;
 
+	func = (OUT_FUNC)dlsym (lib_handle, DLL_BAND_OUT);
 	if (func == NULL)
 	{
 		PF_ERROR_HANDLER (DLL_ERROR, (char*)dlerror ());
 		return 1;
 	}
 
+	conf_print_image (lp_mkcode->lp_prtinfo, lp_image);
+	if (set_band_param (&prt_band, lp_image))
+		return 1;
+
+	magnify.x    = lp_image->magnify.x;
+	magnify.y    = lp_image->magnify.y;
+	print_count.y  = lp_image->print_size.y;
+	margin_count.y = lp_image->negative_margin.y;
+  
 	raster = (UCHAR*)pf_mem_alloc (prt_band.width_bytes + 3);
+	memset ((void*)raster, 0xff, prt_band.width_bytes + 3);
+
 	if (!raster)
 	{
 		PF_ERROR_HANDLER (MEMORY_ERROR, NULL);
 		return 1;
 	}
-
-	memset ((UCHAR*)raster, 0xff, prt_band.width_bytes + 3);
-
-	h_prt_count = lp_image->print_size.y + lp_image->negative_margin.y;
-	h_img_count = 0;
-	h_mag = lp_image->magnify.y;
-
-	for (h_ofs = 0; h_prt_count > 0; h_ofs ++)
+  
+	height_count = 0;
+	for (h_ofs = 0; print_count.y > 0; h_ofs ++)
 	{
-		UCHAR *image;
-		
+		UCHAR *image_band;
+		print_count.x  = lp_image->print_size.x;
+		margin_count.x = lp_image->negative_margin.x;
+
+		width_count = 0;
 		/* imageμ */
-		image = read_raster_image (lp_image);
-		
-		if (!image)
+		image_band = read_raster_image (lp_image);
+		if (image_band == NULL)
 		{
 			PF_ERROR_HANDLER (UNEXPECTED_ERROR, NULL);
 			return 1;
 		}
-		
 		/*  */
-		set_raster (raster, image, lp_image->print_size.x, lp_image->negative_margin.x,
-			    lp_image->magnify.x, lp_image->byte_p_pixel);
-		
-		/*  */
-		while (h_prt_count > 0 && write_judge (h_img_count, h_ofs, h_mag))
+		for (w_ofs = 0; print_count.x > 0; w_ofs++)
 		{
-			if (h_prt_count <= lp_image->print_size.y)
+			while (print_count.x > 0 && write_judge (width_count, w_ofs, magnify.x))
 			{
-				if (band_flush (func, prt_handle, &prt_band, raster, NULL, 0))
+				int i;
+				int bpp = lp_image->byte_p_pixel;
+				UCHAR* to_band;
+
+				if (margin_count.x > 0)
 				{
-					PF_ERROR_HANDLER (LIBPRT_ERROR, lp_mkcode->libprt_path);
-					return 1;
+					width_count ++;
+					margin_count.x--;
+					continue;
 				}
+				to_band = &(raster[(width_count - lp_image->negative_margin.x) * bpp]);
+
+				for (i = 0; i < bpp; i++)
+				{
+					to_band[i] = image_band[w_ofs * bpp + i];
+				}
+				print_count.x--;
+				width_count ++;
 			}
-			h_img_count ++;
-			h_prt_count --;
+		}
+      
+		/*  */
+		while (print_count.y > 0 && write_judge (height_count, h_ofs, magnify.y))
+		{
+			if (margin_count.y > 0)
+			{
+				height_count ++;
+				margin_count.y--;
+				continue;
+			}
+			if (band_flush (func, prt_handle, &prt_band, raster, 0))
+			{
+				PF_ERROR_HANDLER (LIBPRT_ERROR, lp_mkcode->libprt_path);
+				return 1;
+			}
+			print_count.y--;
+			height_count ++;
 		}
 	}
-	
-	if (band_flush (func, prt_handle, &prt_band, NULL, NULL, 1))
+	if (band_flush (func, prt_handle, &prt_band, NULL, 1))
 	{
 		PF_ERROR_HANDLER (LIBPRT_ERROR, lp_mkcode->libprt_path);
 		return 1;
 	}
-	
 	seek_image (lp_image);
-
 	free_band_param (&prt_band);
 	lp_mkcode->conv_status = CONV_STATUS_BAND_OUT;
-
 	return 0;
 }
 
-
 static UCHAR*
 read_raster_image (LP_IMG_STRUCT lp_image)
 {
@@ -908,7 +950,7 @@ conf_print_image (LP_PRT_STRUCT lp_prtinfo, LP_IMG_STRUCT lp_image)
 		lp_image->negative_margin.x = 0;
 		positive_margin_x = lp_prtinfo->margin.x - lp_prtinfo->default_margin.x;
 	}
-	
+
 	if (lp_prtinfo->margin.y < lp_prtinfo->default_margin.y)
 	{
 		lp_image->negative_margin.y = fabs ((double)lp_prtinfo->margin.y
@@ -920,29 +962,22 @@ conf_print_image (LP_PRT_STRUCT lp_prtinfo, LP_IMG_STRUCT lp_image)
 		lp_image->negative_margin.y = 0;
 		positive_margin_y = lp_prtinfo->margin.y - lp_prtinfo->default_margin.y;
 	}
-	
+
 	/* /̾ */
 	lp_image->magnify.x = (double)lp_prtinfo->ratio.x / 100.0;
 	lp_image->magnify.y = (double)lp_prtinfo->ratio.y / 100.0;
-	
+
 	if (lp_prtinfo->bin_id[0] == 'T') /* trim */
 	{
 		double t_mag;
-		double ty_mag;
+                double ty_mag;
+      
+                t_mag = (double)lp_prtinfo->paper_area.x / lp_prtinfo->paper_size.x;
+                ty_mag = (double)lp_prtinfo->paper_area.y / lp_prtinfo->paper_size.y;
+                t_mag = (t_mag > ty_mag) ? t_mag : ty_mag;
 
-		if (!strcmp (lp_prtinfo->bin_id, "TROLL"))
-		{
-			lp_prtinfo->paper_area.y    += lp_prtinfo->default_margin.y * 2;
-			lp_image->negative_margin.y += lp_prtinfo->default_margin.y;
-		}
-
-		t_mag = (double)lp_prtinfo->paper_area.x / lp_prtinfo->paper_size.x;
-		ty_mag = (double)lp_prtinfo->paper_area.y / lp_prtinfo->paper_size.y;
-		t_mag = (t_mag > ty_mag) ? t_mag : ty_mag;
-		
 		lp_image->magnify.x *= t_mag;
 		lp_image->magnify.y *= t_mag;
-
 	}
 
 	/* ΰ */
@@ -976,7 +1011,7 @@ conf_print_image (LP_PRT_STRUCT lp_prtinfo, LP_IMG_STRUCT lp_image)
 
 static void
 set_init_param (LP_LIBPRT_INIT lp_prt_init, LP_PRT_STRUCT lp_prtinfo,
-		FILE* output)
+                FILE* output)
 {
 	lp_prt_init->output       = output;
 
@@ -1027,11 +1062,12 @@ set_band_param (LP_LIBPRT_BAND lp_prt_band, LP_IMG_STRUCT lp_image)
 	width_bytes = WIDTHBYTES(width_pixel * lp_image->byte_p_pixel * 8);
 
 	ex_raster = (UCHAR*)pf_mem_alloc (width_bytes * 2);
-	if (!ex_raster)
+	if (ex_raster == NULL)
 	{
 		PF_ERROR_HANDLER (MEMORY_ERROR, NULL);
 		return 1;
 	}
+
 	lp_prt_band->width_pixel = width_pixel;
 	lp_prt_band->width_bytes = width_bytes;
 	lp_prt_band->byte_data = ex_raster;
@@ -1055,7 +1091,7 @@ write_judge (long count, long point, double mag)
 	long now_count = count + 1;
 
 	if (mag_count < now_count)
-		return 0;			/* 񤭹Ե */
+		return 0;                   /* 񤭹Ե */
 
 	/* 񤭹ߵ */
 	return 1;
@@ -1104,9 +1140,9 @@ escp_through (FILE* infp, FILE* outfp, char* rbuf, int rnum)
 BOOL _2_Line_Flag;
 
 static BOOL
-band_flush (void* func, HANDLE prt_handle,
-	    LP_LIBPRT_BAND lp_prt_band, UCHAR *raster,
-	    UCHAR *atbmp_raster, BOOL flush_flag) /* atbmp_raster̤ */
+band_flush (OUT_FUNC func, HANDLE prt_handle,
+            LP_LIBPRT_BAND lp_prt_band, UCHAR *raster,
+            BOOL flush_flag)
 {
 	UCHAR *target_line;
 
@@ -1119,51 +1155,25 @@ band_flush (void* func, HANDLE prt_handle,
 	else
 	{
 		lp_prt_band->line_number = 2;
-		
 		if (_2_Line_Flag)
+		{
 			target_line = lp_prt_band->byte_data + lp_prt_band->width_bytes;
+		}
 		else
+		{
 			target_line = lp_prt_band->byte_data;
-		
+		}
 		memcpy (target_line, raster, lp_prt_band->width_bytes);
 	}
-	
+
 	if (_2_Line_Flag)
 	{
-		if ((*(OUT_FUNC)func) (prt_handle, lp_prt_band))
-			return 1;			
+		if ((*func) (prt_handle, lp_prt_band))
+		{
+			return 1;
+		}
 	}
 
 	_2_Line_Flag ^= 1;
 	return 0;
 }
-
-
-static void
-set_raster (UCHAR* raster, UCHAR* image_band, int size, int negative, double mag, int bpp)
-{
-	int w_prt_count  = size + negative;
-	double w_mag     = mag;
-	int w_img_count  = 0;
-	int w_ofs;
-
-	for (w_ofs = 0; w_prt_count > 0; w_ofs++)
-	{
-		while (w_prt_count > 0 && write_judge (w_img_count, w_ofs, w_mag))
-		{
-			int i;
-			UCHAR* to_band;
-			
-			if (w_prt_count <= size)
-			{
-				to_band = &(raster[(w_img_count - negative) * bpp]);
-			
-				for (i = 0; i < bpp; i++)
-					to_band[i] = image_band[w_ofs * bpp + i];
-			}
-			w_img_count ++;
-			w_prt_count --;
-		}
-	}
-	return;
-}
