@@ -24,19 +24,20 @@
  * respects for all of the code used other than the libraries which
  * are covered by EPSON KOWA PUBLIC LICENCE.
  */
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #ifndef __PIPSDEF_H__
 #define __PIPSDEF_H__
 
-#define MODE_ITEM 5
-enum MODE_OFSET
-{
-	MOFS_MEDIA = 0,
-	MOFS_INPUT,
-	MOFS_HALFTONE,
-	MOFS_HIGH_SPEED,
-	MOFS_QUALITY
-};
+#if PM900C || PM880C || PM780C || PM3500C || PM790PT || PM920C || PM780CS || PM820CUG || PM3300CUG || SP810_820 || PM730C || PM830C
+#define USE_AUTO_TRIM_4
+#endif
 
+
+
+#define MODE_ITEM 5
 /* output type */
 enum eOUTPUT_FORMAT
 {
@@ -44,15 +45,6 @@ enum eOUTPUT_FORMAT
   PIPS_OUTPUT_CMYKcm
 };
 
-/* ink set */
-enum eINKSET
-{
-  PIPS_INKSET_DEFAULT = 0,
-  PIPS_INKSET_CMYK,
-  PIPS_INKSET_CMYKcm,
-  PIPS_INKSET_CMYKcmDY
-};
-
 /* media size */
 enum ePAPER_SIZE
 {
@@ -109,27 +101,7 @@ enum eMEDIA_TYPE
   PIPS_MED_MATT_HEAVY = 23,
   PIPS_MED_CD_R = 35,
   PIPS_MED_MAT_BOARD = 37,
-  PIPS_MED_NEW_SF = 46,
-  PIPS_MED_CLPP = 51,
-  PIPS_MED_BWIP,
-  PIPS_MED_DBS_MATTE,
-  PIPS_MED_ARCHIVALMATTE,
-  PIPS_MED_PSEMIGLOSS,
-  PIPS_MED_PHOTOWEIGHT,
-  PIPS_MED_ESF,
-  PIPS_MED_EPP,
-  PIPS_MED_IJPC,
-  PIPS_MED_RCPC,  
-  PIPS_MED_GLOSSYPHOTOPAPER,
-  PIPS_MED_MCLP
- 
-};
-
-/* micro weave */
-enum eMICRO_WEAVE
-{
-  PIPS_MW_OFF = 0,
-  PIPS_MW_ON
+  PIPS_MED_CLPP = 51
 };
 
 /* high speed */
@@ -144,7 +116,6 @@ enum eCOLOR_MODE
 {
   PIPS_CMM_PHOTO = 0,
   PIPS_CMM_GRAPH,
-  PIPS_CMM_AUTO,
   PIPS_CMM_NONE
 };
 
@@ -175,10 +146,18 @@ enum eQUALITY
   PIPS_LV_FINE,
   PIPS_LV_SFINE,
   PIPS_LV_PHOTO,
-  PIPS_LV_SPHOTO,
-  PIPS_LV_SILENT
+  PIPS_LV_SPHOTO
 };
 
+/* Ink status */
+enum eINK_STATUS
+{
+  ST_INK_NORMAL = 0,
+  ST_INK_LOW,
+  ST_INK_END
+};
+
+
 #ifndef __PIPS_DEF_H__
 typedef unsigned int UINT;
 typedef unsigned short USHORT;
