@@ -24,6 +24,10 @@
  * respects for all of the code used other than the libraries which
  * are covered by EPSON KOWA PUBLIC LICENCE.
  */
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #ifndef __OPT_H__
 #define __OPT_H__
 
@@ -63,8 +67,80 @@
 #include "optPM900C.rsc"
 #endif
 
-#ifdef PM820C
-#include "optPM820C.rsc"
+#ifdef PM670C
+#include "optPM670C.rsc"
+#endif
+
+#ifdef PM880C
+#include "optPM880C.rsc"
+#endif
+
+#ifdef PM780C
+#include "optPM780C.rsc"
+#endif
+
+#ifdef PM3500C
+#include "optPM3500C.rsc"
+#endif
+
+#ifdef CL700
+#include "optCL700.rsc"
+#endif
+
+#ifdef SC580
+#include "optSC580.rsc"
+#endif
+
+#ifdef SC480
+#include "optSC480.rsc"
+#endif
+
+#ifdef PM790PT
+#include "optPM790PT.rsc"
+#endif
+
+#ifdef SC40S
+#include "optSC40S.rsc"
+#endif
+
+#ifdef SC680_777
+#include "optSC680_777.rsc"
+#endif
+
+#ifdef SC880
+#include "optSC880.rsc"
+#endif
+
+#ifdef SC980
+#include "optSC980.rsc"
+#endif
+
+#ifdef SC20S
+#include "optSC20S.rsc"
+#endif
+
+#ifdef PM720C
+#include "optPM720C.rsc"
+#endif
+
+#ifdef PM780CS
+#include "optPM780CS.rsc"
+#endif
+
+#ifdef PM920C
+#include "optPM920C.rsc"
+#endif
+
+#ifdef PM820CUG
+#include "optPM820CUG.rsc"
+#endif
+
+#ifdef PM3300CUG
+#include "optPM3300CUG.rsc"
+#endif
+
+#ifdef SP810_820
+#include "optSP810_820.rsc"
 #endif
 
 #include "optBase.rsc"
