@@ -30,12 +30,17 @@
 
 #if USE_GTK
 
+#include <unistd.h>
+#include <sys/types.h>
+#include <sys/wait.h>
 #include <string.h>
 #include <ctype.h>
 #include <math.h>
 #include "xMode.h"
-
-typedef struct _IO_SIGDATA{
+#include "ekpcom.h"
+#include "setup.h"
+typedef struct _IO_SIGDATA
+{
 	GtkWidget *filewin;
 	GtkWidget *entry;
 } IO_SIGDATA;
@@ -46,6 +51,8 @@ extern char *input_file;
 extern char *output_file;
 extern int output_type;
 
+extern UTIL_PACK pips_util_pack;
+
 static GtkWidget* commonPixmapLoad(char*);
 
 static RADIO_PACK* radioPackAdd(int);
@@ -67,7 +74,6 @@ static ADJUSTMENT_PACK* adjustmentPackAdd(int);
 static void adjustmentPackSetSensitive(ADJUSTMENT_PACK*, int);
 static void adjustmentPackChengeValue(GtkAdjustment*, ADJUSTMENT_PACK*);
 static void adjustmentPackChengeEntry(GtkWidget*, ADJUSTMENT_PACK*);
-static void adjustmentPackCheckEntry(GtkWidget*, GdkEvent*, ADJUSTMENT_PACK*);
 
 static void ioOutputTypeSet(GtkWidget*, gpointer);
 static GtkWidget* ioPackButton(GtkWidget*);
@@ -77,19 +83,17 @@ static void ioPackCanSel(GtkWidget*, IO_SIGDATA*);
 static void ioPackChengeValue(GtkEntry*, char*);
 
 #ifdef CONV_VERSION2
-static void
-margin_default_set (GtkWidget*, void*);
-static void
-margin_abjset (void);
-static void
-margin_updata (int, long, long);
+static void margin_default_set (GtkWidget*, void*);
+static void margin_abjset (void);
+static void margin_updata (int, long, long);
 
 #endif /* CONV_VERSION2 */
 
 /* ================================================== */
 /*           common functions */
 /* ================================================== */
-static GtkWidget* commonPixmapLoad(char *map)
+static GtkWidget*
+commonPixmapLoad (char *map)
 {
 	GtkWidget *pixmap = NULL;
 	//=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -98,28 +102,33 @@ static GtkWidget* commonPixmapLoad(char *map)
 	return pixmap;
 }
 
-char* commonLabelCall(int id, OPTION_DATA *data)
+char*
+commonLabelCall (int id, OPTION_DATA *data)
 {
 	int i;
 	char *title = NULL;
-	
-	if (data == NULL) {
-		for (i = 0; opt_all[i].id != END_ARRAY; i++) {
-			if(opt_all[i].id == id) {
+
+	if (data == NULL)
+	{
+		for (i = 0; opt_all[i].id != END_ARRAY; i++)
+		{
+			if (opt_all[i].id == id)
 				title = opt_all[i].x_name;
-			}
 		}
-	} else {
+	}
+	else
+	{
 		title = data->x_name;
 	}
-
+  
 	if (title)
 		return (char*)_(title);
-	
+  
 	return NULL;
 }
 
-void commonSetOptionsSensitive(void)
+void
+commonSetOptionsSensitive (void)
 {
 	int i, j, count;
 	int flag[ENTRY_MAX];
@@ -129,59 +138,103 @@ void commonSetOptionsSensitive(void)
 	OPTION_DATA *data;
 	SELECT_PACK *sp;
 
-	sepip_lite = (SEP_INIT_PARAM *)malloc(sizeof(SEP_INIT_PARAM));
+	sepip_lite = (SEP_INIT_PARAM *)malloc (sizeof (SEP_INIT_PARAM));
 
 	count = 0;
 	sp = (SELECT_PACK *)opt_address[P_COLOR_MODE];
-	if(strcmp((char *)options[P_INK], "MONO")){ /* Color */
+	if (strcmp ((char *)options[P_INK], "MONO"))
+	{ /* Color */
 		mode = pModeCol;
 		flag[0] = TRUE;
-		gtk_widget_show(sp->hbox);
+		gtk_widget_show (sp->hbox);
 	}
-	else{ /* mono */
+	else
+	{ /* mono */
 		mode = pModeMono;
 		flag[0] = FALSE;
-		gtk_widget_hide(sp->hbox);
+		gtk_widget_hide (sp->hbox);
 	}
-
-
-	if(strcmp((char *)options[P_COLOR_MODE], "NONE")) flag[1] = TRUE;
+  
+  
+	if (strcmp ((char *)options[P_COLOR_MODE], "NONE")) flag[1] = TRUE;
 	else flag[1] = FALSE;
-	adjustmentPackSetSensitive((ADJUSTMENT_PACK *)opt_address[P_BRIGHTNESS], flag[1]);
-	adjustmentPackSetSensitive((ADJUSTMENT_PACK *)opt_address[P_CONTRAST], flag[1]);
+	adjustmentPackSetSensitive ((ADJUSTMENT_PACK *)opt_address[P_BRIGHTNESS], flag[1]);
+	adjustmentPackSetSensitive ((ADJUSTMENT_PACK *)opt_address[P_CONTRAST], flag[1]);
 
-	if(flag[1]){
-		adjustmentPackSetSensitive((ADJUSTMENT_PACK *)opt_address[P_SATURATION], flag[0]);
-		adjustmentPackSetSensitive((ADJUSTMENT_PACK *)opt_address[P_STRENGTH_CYAN], flag[0]);
-		adjustmentPackSetSensitive((ADJUSTMENT_PACK *)opt_address[P_STRENGTH_MAGENTA], flag[0]);
-		adjustmentPackSetSensitive((ADJUSTMENT_PACK *)opt_address[P_STRENGTH_YELLOW], flag[0]);
+	if (flag[1])
+	{
+		adjustmentPackSetSensitive ((ADJUSTMENT_PACK *)opt_address[P_SATURATION], flag[0]);
+		adjustmentPackSetSensitive ((ADJUSTMENT_PACK *)opt_address[P_STRENGTH_CYAN], flag[0]);
+		adjustmentPackSetSensitive ((ADJUSTMENT_PACK *)opt_address[P_STRENGTH_MAGENTA], flag[0]);
+		adjustmentPackSetSensitive ((ADJUSTMENT_PACK *)opt_address[P_STRENGTH_YELLOW], flag[0]);
 	}
-	else{
-		adjustmentPackSetSensitive((ADJUSTMENT_PACK *)opt_address[P_SATURATION], FALSE);
-		adjustmentPackSetSensitive((ADJUSTMENT_PACK *)opt_address[P_STRENGTH_CYAN], FALSE);
-		adjustmentPackSetSensitive((ADJUSTMENT_PACK *)opt_address[P_STRENGTH_MAGENTA], FALSE);
-		adjustmentPackSetSensitive((ADJUSTMENT_PACK *)opt_address[P_STRENGTH_YELLOW], FALSE);
+	else
+	{
+		adjustmentPackSetSensitive ((ADJUSTMENT_PACK *)opt_address[P_SATURATION], FALSE);
+		adjustmentPackSetSensitive ((ADJUSTMENT_PACK *)opt_address[P_STRENGTH_CYAN], FALSE);
+		adjustmentPackSetSensitive ((ADJUSTMENT_PACK *)opt_address[P_STRENGTH_MAGENTA], FALSE);
+		adjustmentPackSetSensitive ((ADJUSTMENT_PACK *)opt_address[P_STRENGTH_YELLOW], FALSE);
 	}
 
 
 	/* ѥ᡼,Υߡ */
 	sepip_lite->src_resolution.x = sepip_lite->halftone_type
-		= sepip_lite->high_speed = sepip_lite->qlevel = -1;
-	sepip_lite->media_type = getValueOfDatabases(P_MEDIA_TYPE, (char *)options[P_MEDIA_TYPE]);
+		= sepip_lite->high_speed = sepip_lite->qlevel
+		= sepip_lite->media_type = -1;
+
+	/* make new media type entry */
+#ifdef USE_AUTO_TRIM_4
+	{
+		sepip_lite->bin_id = getValueOfDatabases (P_BIN, (char *)options[P_BIN]);
+		sepip_lite->prt_format = getValueOfDatabases (P_INK, (char *)options[P_INK]);
+
+		data = opt_all[P_MEDIA_TYPE].data;
+		for (i = 0; data[i].value != END_ARRAY; i++)
+			flag[i] = FALSE;
+
+		for (i = 0; i < mode[0]; i++)
+		{
+			if (!printModeCheck (mode, i, sepip_lite))
+			{
+				for (j = 0; data[j].value != END_ARRAY; j++)
+				{
+					if (data[j].value == mode[i * MODE_ITEM + 1])
+					{
+						flag[j] = TRUE;
+					}
+				}
+			}
+		}
+
+		count = 0;
+		for (i = 0; data[i].value != END_ARRAY; i++)
+		{
+			if (flag[i] == TRUE)
+			{
+				new_entry[count++] = data[i].rsc_name;
+			}
+		}
+		new_entry[count] = NULL;
+		selectPackSetSensitive ((SELECT_PACK *)opt_address[P_MEDIA_TYPE], new_entry);
+	}
+#endif /* USE_AUTO_TRIM_4 */
 
 	/* make new resolution entry */
+	sepip_lite->media_type = getValueOfDatabases (P_MEDIA_TYPE, (char *)options[P_MEDIA_TYPE]);
 	data = opt_all[P_RESOLUTION].data;
 
-	for(i = 0; data[i].value != END_ARRAY; i++) flag[i] = FALSE;
-	sepip_lite->media_type = getValueOfDatabases(P_MEDIA_TYPE, (char *)options[P_MEDIA_TYPE]);
+	for (i = 0; data[i].value != END_ARRAY; i++)
+		flag[i] = FALSE;
+	sepip_lite->media_type = getValueOfDatabases (P_MEDIA_TYPE, (char *)options[P_MEDIA_TYPE]);
   
 	count = 0;
-	for(i = 0; i < mode[0]; i++){
-		if(!printModeCheck(mode, i, sepip_lite))
+	for (i = 0; i < mode[0]; i++)
+	{
+		if (!printModeCheck (mode, i, sepip_lite))
 		{
-			for(j = 0; data[j].value != END_ARRAY; j++)
+			for (j = 0; data[j].value != END_ARRAY; j++)
 			{
-				if(mode[i * MODE_ITEM + 2] & (int)ldexp(1.0, j))
+				if (mode[i * MODE_ITEM + 2] & (int)ldexp (1.0, j))
 				{
 					flag[j] = TRUE;
 				}
@@ -189,102 +242,120 @@ void commonSetOptionsSensitive(void)
 		}
 	}
 	count = 0;
-	for(i = 0; data[i].value != END_ARRAY; i++)
+	for (i = 0; data[i].value != END_ARRAY; i++)
 	{
-		if(flag[i] == TRUE)
+		if (flag[i] == TRUE)
 		{
 			new_entry[count++] = data[i].rsc_name;
 		}
 	}
 	new_entry[count] = NULL;
-	selectPackSetSensitive((SELECT_PACK *)opt_address[P_RESOLUTION], new_entry);
+	selectPackSetSensitive ((SELECT_PACK *)opt_address[P_RESOLUTION], new_entry);
 
 
 	// make new quality level entry
-	sepip_lite->src_resolution.x = getValueOfDatabases(P_RESOLUTION, (char *)options[P_RESOLUTION]);
+	sepip_lite->src_resolution.x = getValueOfDatabases (P_RESOLUTION, (char *)options[P_RESOLUTION]);
 	data = opt_all[P_QUALITY_LEVEL].data;
 
-	for(i = 0; data[i].value != END_ARRAY; i++) flag[i] = FALSE;
-	for(i = 0; i < mode[0]; i++){
-		if(!printModeCheck(mode, i, sepip_lite)){
+	for (i = 0; data[i].value != END_ARRAY; i++) flag[i] = FALSE;
+	for (i = 0; i < mode[0]; i++)
+	{
+		if (!printModeCheck (mode, i, sepip_lite))
+		{
 			unsigned int bit = mode[i * MODE_ITEM + 5];
 			switch (sepip_lite->src_resolution.x)
 			{
+
 			case 120:
 			case 180: flag[0] = TRUE;
-	  
+	      
 			case 720: bit = bit >> 4;
 			case 360: bit = bit >> 4;
+
+#if SC580 || SC480 || SC40S || SC20S
+			case 240: bit = bit >> 4;
+#endif
+
 			}
 			bit &= 0x0f;
-			for(j = 0; data[j].value != END_ARRAY; j++){
-				if(bit == data[j].value) flag[j] = TRUE;
+			for (j = 0; data[j].value != END_ARRAY; j++)
+			{
+				if (bit == data[j].value) flag[j] = TRUE;
 			}
 		}
 	}
 	count = 0;
-	for(i = 0; data[i].value != END_ARRAY; i++)
-		if(flag[i] == TRUE) new_entry[count++] = data[i].rsc_name;
+	for (i = 0; data[i].value != END_ARRAY; i++)
+		if (flag[i] == TRUE)
+			new_entry[count++] = data[i].rsc_name;
 	new_entry[count] = NULL;
-	selectPackSetSensitive((SELECT_PACK *)opt_address[P_QUALITY_LEVEL], new_entry);
-	selectPackVisibility((SELECT_PACK *)opt_address[P_QUALITY_LEVEL], i - 1);
+	selectPackSetSensitive ((SELECT_PACK *)opt_address[P_QUALITY_LEVEL], new_entry);
+	selectPackVisibility ((SELECT_PACK *)opt_address[P_QUALITY_LEVEL], i - 1);
 
 	/* check high speed sensitive */
 	data = opt_all[P_QUALITY_LEVEL].data;
 
-	for(i = 0; data[i].value != END_ARRAY; i++) flag[i] = FALSE;
-	sepip_lite->qlevel = getValueOfDatabases(P_QUALITY_LEVEL, (char *)options[P_QUALITY_LEVEL]);
+	for (i = 0; data[i].value != END_ARRAY; i++)
+		flag[i] = FALSE;
+	sepip_lite->qlevel = getValueOfDatabases (P_QUALITY_LEVEL, (char *)options[P_QUALITY_LEVEL]);
 
-	for(i = 0; i < mode[0]; i++){
-		if(!printModeCheck(mode, i, sepip_lite))
+	for (i = 0; i < mode[0]; i++)
+	{
+		if (!printModeCheck (mode, i, sepip_lite))
 		{
-			checkPackSetSensitive((CHECK_PACK *)opt_address[P_HIGH_SPEED], mode[i * MODE_ITEM + 4]);
+			checkPackSetSensitive ((CHECK_PACK *)opt_address[P_HIGH_SPEED], mode[i * MODE_ITEM + 4]);
 			goto OUT;
 		}
 	}
  OUT:
-
-
+  
+  
 	/* make halftonetype entry */
 	data = opt_all[P_HALF_TONE].data;
-	for(i = 0; data[i].value != END_ARRAY; i++) flag[i] = FALSE;
+	for (i = 0; data[i].value != END_ARRAY; i++) flag[i] = FALSE;
 
-	for(i = 0; i < mode[0]; i++){
-		if(!printModeCheck(mode, i, sepip_lite)){
-			for(j = 0; data[j].value != END_ARRAY; j++){
-				if(mode[i * MODE_ITEM + 3] & (int)ldexp(1.0, j)) flag[j] = TRUE;
+	for (i = 0; i < mode[0]; i++)
+	{
+		if (!printModeCheck(mode, i, sepip_lite))
+		{
+			for (j = 0; data[j].value != END_ARRAY; j++)
+			{
+				if (mode[i * MODE_ITEM + 3] & (int)ldexp(1.0, j)) flag[j] = TRUE;
 			}
 			goto OUT2;
 		}
 	}
  OUT2:
-
-	count = 0;
-	for(i = 0; data[i].value != END_ARRAY; i++)
-		if(flag[i] == TRUE) new_entry[count++] = data[i].rsc_name;
-	new_entry[count] = NULL;
-	selectPackSetSensitive((SELECT_PACK *)opt_address[P_HALF_TONE], new_entry);
   
-	free(sepip_lite);
+	count = 0;
+	for (i = 0; data[i].value != END_ARRAY; i++)
+		if (flag[i] == TRUE)
+			new_entry[count++] = data[i].rsc_name;
+	new_entry[count] = NULL;
+	selectPackSetSensitive ((SELECT_PACK *)opt_address[P_HALF_TONE], new_entry);
+  
+	free (sepip_lite);
 #ifdef ROLL_PAPER
 	{
 		char **msentry;
-		switch(getValueOfDatabases(P_BIN, (char *)options[P_BIN])){
+		switch (getValueOfDatabases (P_BIN, (char *)options[P_BIN]))
+		{
 		case PIPS_BIN_AUTO: msentry = mediaSizeEntry; break;
 		case PIPS_BIN_USER: msentry = mediaSizeEntry_R; break;
-#if !(PM820_3300C)
+#ifndef PM820_3300C
 		case PIPS_BIN_TRIMBANNER: msentry = mediaSizeEntry_TR; break;
 #else
 		case PIPS_BIN_TB_PM3300C: msentry = mediaSizeEntry_TR_PM3300C; break;
 		case PIPS_BIN_TB_PM820C: msentry = mediaSizeEntry_TR_PM820C; break;
-#endif /* PM820_3300C */
-#if (PM820C)
 		case PIPS_BIN_AUTO_TRIM: msentry = mediaSizeEntry_TA; break;
-#endif /* PM820C */
+#endif /* PM820_3300C */
+#ifdef USE_AUTO_TRIM_4
+		case PIPS_BIN_AUTO_TRIM_4: msentry = mediaSizeEntry_NMA; break;
+#endif /* USE_AUTO_TRIM_4 */
 
-		default: return;
+		default: abort ();
 		}
-		selectPackSetSensitive((SELECT_PACK *)opt_address[P_MEDIA_SIZE], msentry);
+		selectPackSetSensitive ((SELECT_PACK *)opt_address[P_MEDIA_SIZE], msentry);
 	}
 #endif /* ROLL_PAPER */
 
@@ -320,9 +391,11 @@ static void radioPackChengeValue(GtkWidget *widget, RADIO_PACK *rp)
 	int i, id;
 
 	id = rp->id;
-	for(i = 0; (node = g_slist_nth(rp->group, i)) != NULL; i++){
+	for(i = 0; (node = g_slist_nth(rp->group, i)) != NULL; i++)
+	{
 		radio = (GtkWidget *)node->data;
-		if(radio == widget){
+		if(radio == widget)
+		{
 			options[id] = (void *)opt_all[id].data[i].rsc_name;
 			break;
 		}
@@ -355,33 +428,44 @@ GtkWidget* radioPackNew(char *map, char *entry[], int id)
 	for(offset = 0; entry[offset] != NULL; offset++);
 	if((data = databasesCall(CALL_FOR_RSC_NAME, id, (void*)entry[--offset])) == NULL)
 		return NULL;
-	radio = gtk_radio_button_new_with_label(NULL,
-						commonLabelCall(id, data));
+
+	radio = gtk_radio_button_new_with_label(NULL, commonLabelCall(id, data));
+
 	if(!strcmp(data->rsc_name, (char*)options[id]))
 		gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(radio), TRUE);
-	else gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(radio), FALSE);
+
+	else
+		gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(radio), FALSE);
+
 	gtk_signal_connect(GTK_OBJECT(radio), "pressed",
 			   GTK_SIGNAL_FUNC(radioPackChengeValue), sig_id);
 
 	gtk_box_pack_start(GTK_BOX(hbox), radio, FALSE, FALSE, 0);
 	gtk_widget_show(radio);
+
 	group = gtk_radio_button_group(GTK_RADIO_BUTTON(radio));
+
 	offset--;
-	for(; offset >= 0; offset--){
+	for(; offset >= 0; offset--)
+	{
 		if((data = databasesCall(CALL_FOR_RSC_NAME, id, (void*)entry[offset])) == NULL)
 			return NULL;
-		radio = gtk_radio_button_new_with_label(group,
-							commonLabelCall(id, data));
+	  
+		radio = gtk_radio_button_new_with_label(group, commonLabelCall(id, data));
+
 		if(!strcmp(data->rsc_name, (char*)options[id]))
 			gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(radio), TRUE);
-		else gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(radio), FALSE);
+
+		else
+			gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(radio), FALSE);
+
 		gtk_signal_connect(GTK_OBJECT(radio), "pressed",
 				   GTK_SIGNAL_FUNC(radioPackChengeValue), sig_id);
 		gtk_box_pack_start(GTK_BOX(hbox), radio, FALSE, FALSE, 0);
 		gtk_widget_show(radio);
+		group = gtk_radio_button_group(GTK_RADIO_BUTTON(radio));
 	}
-	group = gtk_radio_button_group(GTK_RADIO_BUTTON(radio));
-  
+
 	gtk_container_add(GTK_CONTAINER(frame), hbox);
 	gtk_widget_show(hbox);
 
@@ -558,12 +642,10 @@ static void selectPackChengeValue(GtkWidget *widget, SELECT_PACK *sp)
 	commonSetOptionsSensitive();
 
 	/* set margin abjustment  -add Mon Aug 28 2000 sk */
-#ifdef CONV_VERSION2
 	if (id == P_MEDIA_SIZE || id == P_BIN)
 	{
 		margin_default_set (NULL, NULL);
 	}
-#endif /* CONV_VERSION2 */
 }
 
 
@@ -786,34 +868,6 @@ static void adjustmentPackChengeEntry(GtkWidget* widget,
 	return;
 }
 
-static void adjustmentPackCheckEntry(GtkWidget* widget,
-				     GdkEvent* event, ADJUSTMENT_PACK *ap )
-{
-	int id, *opt_value, len;
-	char* strval;
-
-	/* check only for NULL */
-
-	id = ap->id;
-	opt_value = (int *)options[id];
-	strval = (char*)gtk_entry_get_text(GTK_ENTRY(widget));
-
-	
-	len = strlen(strval);
-	/* ʸ¸ߤƤ, 夬0ǤʤOK */
-	if ((len == 0)
-	    || ((len > 1) && ((strval[0] == '0')
-			      || (strval[0] == '-') && (strval[1] == '0'))))
-	{
-		gtk_signal_handler_block_by_data (GTK_OBJECT(widget), (gpointer)ap);
-		/* *opt_value = 0; */
-		sprintf (strval, "%d", *opt_value );
-		gtk_entry_set_text(GTK_ENTRY(widget), strval);
-		gtk_signal_handler_unblock_by_data (GTK_OBJECT(widget), (gpointer)ap);
-	}
-	return;
-}
-
 GtkWidget* adjustmentPackNew(char *map, int id, double param[])
 {
 	GtkWidget *hbox;
@@ -853,9 +907,6 @@ GtkWidget* adjustmentPackNew(char *map, int id, double param[])
 	gtk_widget_show(entry);
 	gtk_signal_connect(GTK_OBJECT(entry), "changed",
 			   GTK_SIGNAL_FUNC(adjustmentPackChengeEntry), sig_id);
-	/* focus out */
-	gtk_signal_connect(GTK_OBJECT(entry), "focus_out_event",
-			   GTK_SIGNAL_FUNC(adjustmentPackCheckEntry), sig_id );
 
 	adj = gtk_adjustment_new(*value, param[0], param[1],
 				 param[2], param[3], param[4]);
@@ -925,7 +976,8 @@ GtkWidget* ioPackNew(char *title, int flag)
 	if(flag == OUTPUT){
 		ip = (IO_PACK *)malloc(sizeof(IO_PACK));
 		ip->hbox = hbox;
-		radio = gtk_radio_button_new_with_label(NULL, _(outputLabels[0]));
+		radio = gtk_radio_button_new_with_label(NULL,
+							(char*)_(outputLabels[0]));
 		gtk_box_pack_start(GTK_BOX(vbox), radio, FALSE, TRUE, 0);
 		ip->label = outputLabels[0];
 		gtk_signal_connect(GTK_OBJECT(radio), "clicked",
@@ -933,7 +985,8 @@ GtkWidget* ioPackNew(char *title, int flag)
 		gtk_widget_show(radio);
 
 		group = gtk_radio_button_group(GTK_RADIO_BUTTON(radio));
-		radio = gtk_radio_button_new_with_label(group, (char*)_(outputLabels[1]));
+		radio = gtk_radio_button_new_with_label(group,
+							(char*)_(outputLabels[1]));
 		gtk_box_pack_start(GTK_BOX(vbox), radio, FALSE, TRUE, 0);
 		gtk_signal_connect(GTK_OBJECT(radio), "clicked",
 				   GTK_SIGNAL_FUNC(ioOutputTypeSet), NULL);
@@ -1129,13 +1182,394 @@ margin_updata (int id, long def, long max)
 	SPIN_PACK *mg = (SPIN_PACK*)opt_address[id];
 
 	adj = gtk_spin_button_get_adjustment (GTK_SPIN_BUTTON(mg->spin));
-	adj->upper = DOT_TO_MM(max)  - 1; /* ޡͤ1mmʤꤹ */
+	adj->upper = DOT_TO_MM(max);
 	gtk_spin_button_set_adjustment (GTK_SPIN_BUTTON(mg->spin), GTK_ADJUSTMENT(adj));
-	if (*((int*)options[id]) > (DOT_TO_MM(max) - 1)) /* Ʊͤ˥ޡͤ򾯤ʤ */
+	if (*((int*)options[id]) > DOT_TO_MM(max))
 		gtk_adjustment_set_value (GTK_ADJUSTMENT(adj), (gfloat)DOT_TO_MM(def));
 
 	return;
 }
 #endif /* CONV_VERSION2 */
 
+
+/* Utility  -add Mon Feb 12 2001 */
+
+static void checkInkResidual (char *);
+static void setInkProgress (char *);
+static void commandButtonClicked (GtkWidget *, char *);
+static int utilInkChecker (char*);
+static GtkWidget* createMsgErr (char*);
+
+GtkWidget*
+commandButtonNew (char* text)
+{
+	GtkWidget *hbox, *label, *button;
+  
+	hbox = gtk_hbox_new(TRUE, GTK_BORDER);
+
+	label = gtk_label_new(text);
+	gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
+	gtk_widget_show(label);
+  
+	button = gtk_button_new_with_label("OK");
+	gtk_signal_connect (GTK_OBJECT(button), "clicked",
+			    GTK_SIGNAL_FUNC(commandButtonClicked), text);
+/*    gtk_widget_set_usize (GTK_WIDGET(button), 0, 20); */
+	gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
+	gtk_widget_show(button);
+  
+	return hbox;
+}
+
+
+GtkWidget*
+progressPackNew (char* text)
+{
+	GtkWidget *hbox, *label, *prog;
+
+	hbox = gtk_hbox_new(TRUE, GTK_BORDER);
+
+	label = gtk_label_new (text);
+	gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
+	gtk_widget_show(label);
+
+	prog = gtk_progress_bar_new ();
+	gtk_box_pack_start(GTK_BOX(hbox), prog, TRUE, TRUE, 0);
+	gtk_widget_show(prog);
+
+	if (strcmp (text, (char *)_(Ink_Black)) == 0)
+	{
+		pips_util_pack.black_prog = prog;
+	}
+	else
+	{
+		pips_util_pack.color_prog = prog;
+	}
+
+	return hbox;
+}
+
+
+int
+getPrinterStatus (void *data)
+{
+	char rep_buf[REPLAY_SIZE];
+	char status_command[]  = { 's', 't', 0x01, 0x00, 0x01 };
+	int nwrite, nread;
+
+	nwrite = sizeof (status_command);
+	nread = 0;
+	if (sock_write (status_command, &nwrite) < 0)
+	{
+		sock_reopen ();
+		nwrite = sizeof (status_command);
+		sock_write (status_command, &nwrite);
+	}
+  
+	if (nwrite > 0)
+	{
+		nread = REPLAY_SIZE;
+		sock_read (rep_buf, &nread);
+	}
+
+	checkInkResidual (rep_buf);
+	setInkProgress (rep_buf);
+
+	return 1;		       /* timerƤӽФؿTRUE֤ʤȽλƤޤ */
+}
+
+static void
+checkInkResidual (char *buf)
+{
+	char* point;
+
+	point = strstr (buf, "ER:");
+	if (point != NULL && (memcmp (point + 3, "05", 2) == 0))
+	{
+		pips_util_pack.ink_low_flag = ST_INK_END;
+		return;
+	}
+
+	point = strstr (buf, "WR:");
+	if (point != NULL)
+	{
+		pips_util_pack.ink_low_flag = ST_INK_LOW;
+		return;
+	}
+
+	pips_util_pack.ink_low_flag = ST_INK_NORMAL;
+	return;
+}
+
+static void
+setInkProgress (char *buf)
+{
+	char* point;
+
+	point = strstr(buf, "IQ:");
+	if (point)
+	{
+		char K[3], C[3], M[3], Y[3];
+		char LC[3], LM[3], DY[3];
+		int rest, black_rest, color_rest;
+		char *stopstring;
+
+		memcpy (K, "-1", 3);
+		memcpy (C, "-1", 3);
+		memcpy (M, "-1", 3);
+		memcpy (Y, "-1", 3);
+		memcpy (LC, "-1", 3);
+		memcpy (LM, "-1", 3);
+		memcpy (DY, "-1", 3);
+
+		black_rest = color_rest = 0;
+		strncpy (K, point + 3, 2);
+		strncpy (C, point + 5, 2);
+		strncpy (M, point + 7, 2);
+		strncpy (Y, point + 9, 2);
+      
+      		if (point[11] != ';')	/* 6 ink */
+		{
+			strncpy(LC, point + 11, 2);
+			strncpy(LM, point + 13, 2);
+			
+			if (point[15] != ';')	/* 7 ink */
+				strncpy(DY, point + 15, 2);
+		}
+
+		black_rest = (gint)strtol (K, &stopstring, 16);
+		color_rest = (gint)strtol (C, &stopstring, 16);
+      
+		rest = strtol (M, &stopstring, 16);
+		color_rest = (rest < color_rest) ? rest : color_rest;
+		rest = strtol(Y, &stopstring, 16);
+		color_rest = (rest < color_rest) ? rest : color_rest;
+
+		rest = strtol (LC, &stopstring, 16);
+		if ((rest >= 0) && ((gint)rest < color_rest)) color_rest = (gint)rest; 
+    
+		rest = strtol (LM, &stopstring, 16);
+		if ((rest >= 0) && ((gint)rest < color_rest)) color_rest = (gint)rest; 
+
+		rest = strtol (DY, &stopstring, 16);
+		if ((rest >= 0) && ((gint)rest < color_rest)) color_rest = (gint)rest; 
+
+		gtk_progress_bar_update(GTK_PROGRESS_BAR(pips_util_pack.black_prog),
+					(gfloat)black_rest / 100.0);
+		gtk_progress_bar_update(GTK_PROGRESS_BAR(pips_util_pack.color_prog),
+					(gfloat)color_rest / 100.0);
+		gtk_widget_hide (pips_util_pack.no_connect_frame);
+		gtk_widget_show (pips_util_pack.connect_frame);
+	}
+	else
+	{
+		gtk_widget_hide (pips_util_pack.connect_frame);
+		gtk_widget_show (pips_util_pack.no_connect_frame);
+	}
+	return;
+}
+
+
+static void
+commandButtonClicked (GtkWidget *widget, char* text)
+{
+	/* D4
+	   int nwrite;
+	   char pattern_command[] = { 'n', 'c', 0x01, 0x00, 0x00 };
+	   char cleaning_command[] = { 'c', 'h', 0x01, 0x00, 0x01 };
+	*/
+	char pattern_command[] = {
+		0x00, 0x00, 0x00, 0x1b, 0x01, 0x40, 0x45, 0x4a,
+		0x4c, 0x20, 0x31, 0x32, 0x38, 0x34, 0x2e, 0x34,
+		0x0a, 0x40, 0x45, 0x4a, 0x4c, 0x20, 0x20, 0x20,
+		0x20, 0x20, 0x0a,
+    
+		0x1b, 0x40, 0x1b, 0x40,
+		0x1b, 0x28, 0x52, 0x08, 0x00, 0x00, 0x52, 0x45,
+		0x4d, 0x4f, 0x54, 0x45, 0x31,
+
+		'N', 'C', 0x02, 0x00, 0x00, 0x00,
+
+		0x1b, 0x00, 0x00, 0x00,
+		0x0d, 0x0a, 0x0d, 0x0a,
+
+		0x1b, 0x40, 0x1b, 0x40,
+		0x1b, 0x28, 0x52, 0x08, 0x00, 0x00, 0x52, 0x45,
+		0x4d, 0x4f, 0x54, 0x45, 0x31,
+
+		'V', 'I', 0x02, 0x00, 0x00, 0x00,
+		/*  'J', 'E', 0x01, 0x00, 0x00, */
+
+		0x1b, 0x00, 0x00, 0x00,
+		0x0c,
+
+		0x1b, 0x40, 0x1b, 0x40
+	};
+
+	char cleaning_command[] = {
+		0x00, 0x00, 0x00, 0x1b, 0x01, 0x40, 0x45, 0x4a,
+		0x4c, 0x20, 0x31, 0x32, 0x38, 0x34, 0x2e, 0x34,
+		0x0a, 0x40, 0x45, 0x4a, 0x4c, 0x20, 0x20, 0x20,
+		0x20, 0x20, 0x0a,
+    
+		0x1b, 0x40, 0x1b, 0x40,
+		0x1b, 0x28, 0x52, 0x08, 0x00, 0x00, 0x52, 0x45,
+		0x4d, 0x4f, 0x54, 0x45, 0x31,
+
+		'C', 'H', 0x02, 0x00, 0x00, 0x00,
+		/*  'J', 'E', 0x01, 0x00, 0x00, */
+    
+		0x1b, 0x00, 0x00, 0x00,
+
+		0x1b, 0x40, 0x1b, 0x40
+	};
+	FILE* fp;
+	char navi_command[256];
+
+	if (!strcmp (text, _(Status_Monitor)))
+	{
+		system ("ekpstm 2> /dev/null &");
+	}
+	else
+	{
+		char prt_command[107];
+      
+
+		if (utilInkChecker (text))
+			return;
+
+		strcpy (prt_command, "lpr -P");
+		get_prt_name (prt_command + 6);
+      
+		if (!strcmp (text, _(Nozzle_Check)))
+		{
+			fp = popen (prt_command, "w");
+			fwrite (pattern_command, sizeof (pattern_command), 1, fp);
+			pclose (fp);
+			/* D4
+			   nwrite = sizeof (pattern_command);
+			   sock_write_abandon_reply (pattern_command, &nwrite);
+			*/
+		}
+		else if (!strcmp (text, _(Head_Cleaning)))
+		{
+			fp = popen (prt_command, "w");
+			fwrite (cleaning_command, sizeof (cleaning_command), 1, fp);
+			pclose (fp);
+			/* D4
+			   nwrite = sizeof (cleaning_command);
+			   sock_write_abandon_reply (cleaning_command, &nwrite);
+			*/
+		}
+		else
+		{
+			/* !!!! ¸ */
+			if (!strcmp (text, _(Print_Head_Alignment)))
+			{
+#if PM880C || PM3500C
+				sprintf (navi_command, NAVI_PATH " --alignment --printer \"%s\" --ruled 3 --patch 2 --platen", prt_command);
+#elif PM900C || PM920C
+				sprintf (navi_command, NAVI_PATH " --alignment --printer \"%s\" --ruled 2 --patch 1 --platen", prt_command);
+#elif SC40S || SC20S || SP810_820 || SC60S
+				sprintf (navi_command, NAVI_PATH " --alignment --printer \"%s\" --ruled 3 --rpath " RULED_PATH , prt_command);
+#elif SC980
+				sprintf (navi_command, NAVI_PATH " --alignment --printer \"%s\" --ruled 2", prt_command);
+#else
+				sprintf (navi_command, NAVI_PATH " --alignment --printer \"%s\" --ruled 3", prt_command);
+#endif
+			}
+			else if (!strcmp (text, _(Ink_Chenge)))
+				sprintf (navi_command, NAVI_PATH " --ink");
+	  
+			strcat (navi_command, " 2> /dev/null");
+			system (navi_command);
+		}
+	}
+	return;
+}
+
+static int
+utilInkChecker (char* text)
+{
+	if ((pips_util_pack.ink_low_flag == ST_INK_END)
+	    || (pips_util_pack.ink_low_flag == ST_INK_LOW
+		&& !strcmp (text, _(Head_Cleaning))))
+	{
+		GtkWidget *widget;
+
+		widget = createMsgErr (text);
+		gtk_widget_show (widget);
+
+		return 1;
+	}
+	return 0;
+}
+
+void
+push_ok (GtkButton *button, gpointer p_dialog)
+{
+	gtk_widget_destroy (p_dialog);
+	return;
+}
+
+static GtkWidget*
+createMsgErr (char* text)
+{
+	GtkWidget *msg_dialog;
+	GtkWidget *dialog_vbox;
+	GtkWidget *label;
+	GtkWidget *dialog_action_area1;
+	GtkWidget *msg_ok_button;
+
+	if (!strcmp (text, _(Nozzle_Check)))
+		label = gtk_label_new (_(Nozzle_Check_Err_Msg));
+
+	else if (!strcmp (text, _(Head_Cleaning)))
+		label = gtk_label_new (_(Head_Cleaning_Err_Msg));
+
+	else if (!strcmp (text, _(Print_Head_Alignment)))
+		label = gtk_label_new (_(Head_Alignment_Err_Msg));
+
+	else
+		label = gtk_label_new (_(Utility_Err_Msg));
+
+
+	msg_dialog = gtk_dialog_new ();
+	gtk_object_set_data (GTK_OBJECT (msg_dialog), "msg_err", msg_dialog);
+	gtk_window_set_title (GTK_WINDOW (msg_dialog), _("Error"));
+	GTK_WINDOW (msg_dialog)->type = GTK_WINDOW_DIALOG;
+	gtk_window_set_modal (GTK_WINDOW (msg_dialog), TRUE);
+	gtk_window_set_policy (GTK_WINDOW (msg_dialog), FALSE, FALSE, FALSE);
+
+	dialog_vbox = GTK_DIALOG (msg_dialog)->vbox;
+	gtk_object_set_data (GTK_OBJECT (msg_dialog), "dialog_vbox", dialog_vbox);
+	gtk_widget_show (dialog_vbox);
+
+	gtk_widget_ref (label);
+	gtk_object_set_data_full (GTK_OBJECT (msg_dialog), "label", label,
+				  (GtkDestroyNotify) gtk_widget_unref);
+	gtk_widget_show (label);
+	gtk_box_pack_start (GTK_BOX (dialog_vbox), label, FALSE, FALSE, 0);
+	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+	gtk_misc_set_padding (GTK_MISC (label), 20, 20);
+
+	dialog_action_area1 = GTK_DIALOG (msg_dialog)->action_area;
+	gtk_object_set_data (GTK_OBJECT (msg_dialog), "dialog_action_area1", dialog_action_area1);
+	gtk_widget_show (dialog_action_area1);
+	gtk_container_set_border_width (GTK_CONTAINER (dialog_action_area1), 10);
+
+	msg_ok_button = gtk_button_new_with_label (_("OK"));
+	gtk_widget_ref (msg_ok_button);
+	gtk_object_set_data_full (GTK_OBJECT (msg_dialog), "msg_ok_button", msg_ok_button,
+				  (GtkDestroyNotify) gtk_widget_unref);
+	gtk_widget_show (msg_ok_button);
+	gtk_box_pack_start (GTK_BOX (dialog_action_area1), msg_ok_button, FALSE, TRUE, 0);
+
+	gtk_signal_connect (GTK_OBJECT (msg_ok_button), "clicked",
+			    GTK_SIGNAL_FUNC (push_ok),
+			    msg_dialog);
+
+	return msg_dialog;
+}
+
 #endif /* USE_GTK */
